import { providers, ContractTransaction, Contract } from 'ethers';
import { Certificate, IClaimData, ICertificate, IData, CertificateSchemaVersion } from './Certificate';
import { IBlockchainEvent } from '../utils/events';
import { IBlockchainProperties } from './BlockchainProperties';
export interface IShareInCertificate {
    [address: string]: string;
}
export declare const encodeClaimData: (schemaVersion: CertificateSchemaVersion, claimData: IClaimData) => string;
export declare const decodeClaimData: (schemaVersion: CertificateSchemaVersion, encodedClaimData: string) => IClaimData;
export declare const encodeData: (data: IData) => string;
export declare const decodeData: (encodedData: string) => IData;
export declare function getAllCertificates(blockchainProperties: IBlockchainProperties, schemaVersionMap: Record<number, CertificateSchemaVersion>): Promise<Certificate[]>;
export declare function getAllOwnedCertificates(blockchainProperties: IBlockchainProperties, schemaVersionMap: Record<number, CertificateSchemaVersion>): Promise<Certificate[]>;
export declare function decodeEvent(eventName: string, event: providers.Log, contract: Contract): Promise<IBlockchainEvent>;
export declare const getAllCertificateEvents: (certId: number, blockchainProperties: IBlockchainProperties) => Promise<IBlockchainEvent[]>;
export declare const calculateOwnership: (certificateId: ICertificate['id'], blockchainProperties: IBlockchainProperties, creationBlockNumber?: number) => Promise<IShareInCertificate>;
export declare const calculateClaims: (certificateId: ICertificate['id'], blockchainProperties: IBlockchainProperties, creationBlockNumber?: number) => Promise<IShareInCertificate>;
export declare function approveOperator(operator: string, blockchainProperties: IBlockchainProperties): Promise<ContractTransaction>;
export declare function isApprovedForAll(operator: string, blockchainProperties: IBlockchainProperties): Promise<boolean>;
